<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-randomnana

_✨ 一款开箱即用的随机抽取神乐七奈表情包图片的插件（适用于Nonebot2 V11）✨_

<a href="./LICENSE">
    <img src="https://camo.githubusercontent.com/6849e28a50157229c6a1426570610ecbe589c68bd7c806f4f7513d7265db8cf2/68747470733a2f2f696d672e736869656c64732e696f2f6769746875622f6c6963656e73652f6e6f6e65706c7567696e2f6e6f6e65626f742d706c7567696e2d706574706574" alt="license">
</a><img src="https://img.shields.io/badge/nonebot-2.0.0b5+-red.svg" alt="NoneBot">
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 📖 介绍

一款开箱即用的随机抽取神乐七奈表情包图片的插件（适用于Nonebot2 V11），目前共180张

## 💿 安装

直接把文件夹丢进plugins里即可

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 范围 |
|:-----:|:----:|:----:|:----:|
| 狗妈 | 所有人 | 否 | 群聊 |
| 随机狗妈 | 所有人 | 否 | 群聊 |
### 效果图

<div align="left">
  <img src="https://github.com/NanakoOfficial/nonebot-plugin-randomnana/blob/main/xiaoguo.png"/>
</div>

